Welcome to SynDisco’s documentation! — SynDisco 1.0.0 documentation

# Welcome to SynDisco’s documentation!

Welcome to the official documentation of SynDisco! This project provides a lightweight framework for creating, managing, annotating, and analyzing synthetic discussions between Large Language Model (LLM) user-agents in online forums.

Warning

Active Development

This project is currently in active development. The API is subject to change at any time without prior notice.

We recommend keeping an eye on updates and version releases if you’re using this project in your applications.

Any bug reports or feature requests are welcome!

# Introduction

- Overview
- Features
- Installation
- Guides
  - How to Create a Synthetic Discussion
  - How to Annotate your Synthetic Discussions
  - How to Use the Experiment API to Manage Large-Scale Studies

# Indices and tables

- Index

- Module Index

- Search Page